(ns wanijo.auth
  (:require [compojure.core :refer [POST GET defroutes]]
            [ring.util.response :refer [redirect]]
            [ring.util.anti-forgery :refer [anti-forgery-field]]
            [buddy.hashers :as hashers]
            [hiccup.form :as hform]
            [wanijo.view.page :as page]
            [wanijo.domain.user :as domain-user]))

(defn- login-check! [req]
  (let [{{:keys [uname pw]} :params} req
        unode (domain-user/find! uname)
        pwmatch (when-let [hash (:pw unode)]
                  (hashers/check pw hash))]
    (if pwmatch
      (-> (redirect "/")
          (assoc-in [:session :ident] uname)
          (assoc-in [:session :uuid] (:uuid unode)))
      (-> (redirect "/login")
          (assoc :flash :invalid-credentials)))))

(defn login [req]
  (page/layout!
   :content
   [[:h1 "Kama ken"]
    (hform/form-to
     [:post "/login-check"]
     (when (:flash req) [:section.flash (:flash req)])
     ;;
     (hform/label "uname" "Nimi")
     (hform/text-field {:required "required"} "uname")
     ;;
     (hform/label "pw" "Toki Pimeja")
     (hform/password-field {:required "required"} "pw")
     ;;
     (hform/submit-button "Kama")
     (anti-forgery-field))]))

(defroutes auth-routes
  (GET "/login" [] login)
  (POST "/login-check" [] login-check!)
  (GET "/logout" [] (fn [_] (-> (redirect "/login")
                                (assoc :session nil)))))
