(ns wanijo.handler
  (:require [compojure.core
             :refer [defroutes routes]]
            [compojure.route :as route]
            [ring.middleware.defaults
             :refer [wrap-defaults site-defaults]]
            [ring.util.response :as rur]
            [ring.middleware.session.cookie :as session-cookie]
            [wanijo.auth :refer [auth-routes]]
            [wanijo.home.routes :refer [home-routes]]
            [wanijo.schema.routes :refer [schema-routes]]
            [wanijo.devmode :as devmode]))

(defn- wrap-login-redirect [handler]
  (fn [req]
    (if (get-in req [:session :ident])
      (handler req)
      (rur/redirect "/login"))))

(defroutes app-routes
  (routes auth-routes)
  (wrap-login-redirect
   (routes home-routes
           schema-routes))
  (route/not-found "Not Found"))

(def app
  (-> app-routes
      devmode/wrap-devmode
      (wrap-defaults
       (assoc-in site-defaults
                 [:session :store]
                 (session-cookie/cookie-store
                  {:key "1234567890123456"})))))
